@@ -62,7 +62,8 @@ QStringList findSessions()
     QStringList sessionrcs;
     for (const QString& dir : sessionDirs) {
         QDir d(dir);
-        Q_FOREACH(const QString& sessionDir, d.entryList(QDir::Dirs)) {
+        const auto dirEntries = d.entryList(QDir::Dirs);
+        for (const QString& sessionDir : dirEntries) {
             QDir sd(d.absoluteFilePath(sessionDir));
             QString path(sd.filePath(QStringLiteral("sessionrc")));
             if(QFile::exists(path)) {
@@ -103,8 +104,8 @@ void KDevelopSessionsEngine::updateSessions()
     {
         const Session& session = it2.value();
 
-        if ( !m_currentSessions.contains( session.hash ) )
-        {
+        auto sessionIt = m_currentSessions.constFind(session.hash);
+        if (sessionIt == m_currentSessions.constEnd()) {
             // Publish new session.
 
             m_currentSessions.insert( session.hash, session );
@@ -115,7 +116,7 @@ void KDevelopSessionsEngine::updateSessions()
         {
             // Publish data changes for older sessions.
 
-            Session oldSession( m_currentSessions.value(session.hash) );
+            Session oldSession(*sessionIt);
 
             bool modified = false;
 
