@@ -15,7 +15,7 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
-*/
+ */
 
 #include "archivetemplateloader.h"
 
@@ -33,12 +33,12 @@ public:
 
 ArchiveTemplateLoader* ArchiveTemplateLoader::self()
 {
-    static ArchiveTemplateLoader* loader = new ArchiveTemplateLoader;
+    static auto* loader = new ArchiveTemplateLoader;
     return loader;
 }
 
 ArchiveTemplateLoader::ArchiveTemplateLoader()
-: d(new ArchiveTemplateLoaderPrivate)
+    : d_ptr(new ArchiveTemplateLoaderPrivate)
 {
 }
 
@@ -46,27 +46,32 @@ ArchiveTemplateLoader::~ArchiveTemplateLoader() = default;
 
 void ArchiveTemplateLoader::addLocation(ArchiveTemplateLocation* location)
 {
+    Q_D(ArchiveTemplateLoader);
+
     d->locations.append(location);
 }
 
 void ArchiveTemplateLoader::removeLocation(ArchiveTemplateLocation* location)
 {
+    Q_D(ArchiveTemplateLoader);
+
     d->locations.removeOne(location);
 }
 
 bool ArchiveTemplateLoader::canLoadTemplate(const QString& name) const
 {
-    foreach(ArchiveTemplateLocation* location, d->locations) {
-        if (location->hasTemplate(name)) {
-            return true;
-        }
-    }
-    return false;
+    Q_D(const ArchiveTemplateLoader);
+
+    return std::any_of(d->locations.constBegin(), d->locations.constEnd(), [&](ArchiveTemplateLocation* location) {
+        return (location->hasTemplate(name));
+    });
 }
 
 Grantlee::Template ArchiveTemplateLoader::loadByName(const QString& name, const Grantlee::Engine* engine) const
 {
-    foreach(ArchiveTemplateLocation* location, d->locations) {
+    Q_D(const ArchiveTemplateLoader);
+
+    for (ArchiveTemplateLocation* location : qAsConst(d->locations)) {
         if (location->hasTemplate(name)) {
             return engine->newTemplate(location->templateContents(name), name);
         }
@@ -75,14 +80,14 @@ Grantlee::Template ArchiveTemplateLoader::loadByName(const QString& name, const
     return Grantlee::Template();
 }
 
-QPair< QString, QString > ArchiveTemplateLoader::getMediaUri(const QString& fileName) const
+QPair<QString, QString> ArchiveTemplateLoader::getMediaUri(const QString& fileName) const
 {
     Q_UNUSED(fileName);
     return QPair<QString, QString>();
 }
 
 ArchiveTemplateLocation::ArchiveTemplateLocation(const KArchiveDirectory* directory)
-: m_directory(directory)
+    : m_directory(directory)
 {
     ArchiveTemplateLoader::self()->addLocation(this);
 }
@@ -99,7 +104,7 @@ bool ArchiveTemplateLocation::hasTemplate(const QString& name) const
 
 QString ArchiveTemplateLocation::templateContents(const QString& name) const
 {
-    const KArchiveFile* file = dynamic_cast<const KArchiveFile*>(m_directory->entry(name));
+    const auto* file = dynamic_cast<const KArchiveFile*>(m_directory->entry(name));
     Q_ASSERT(file);
     return QString::fromUtf8(file->data());
 }
