@@ -24,7 +24,6 @@
 #include <QMutexLocker>
 #include <QThread>
 
-#include <qtcompat_p.h>
 #include <interfaces/idocument.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iplugin.h>
@@ -46,18 +45,11 @@ QString KEY_SupportedMimeTypes() { return QStringLiteral("X-KDevelop-SupportedMi
 QString KEY_ILanguageSupport() { return QStringLiteral("ILanguageSupport"); }
 }
 
-#if QT_VERSION < 0x050600
-inline uint qHash(const QMimeType& mime, uint seed = 0)
-{
-    return qHash(mime.name(), seed);
-}
-#endif
-
 namespace KDevelop {
 
 
-typedef QHash<QString, ILanguageSupport*> LanguageHash;
-typedef QHash<QString, QList<ILanguageSupport*> > LanguageCache;
+using LanguageHash = QHash<QString, ILanguageSupport*>;
+using LanguageCache = QHash<QString, QList<ILanguageSupport*>>;
 
 class LanguageControllerPrivate
 {
@@ -93,7 +85,7 @@ public:
 
     LanguageHash languages; //Maps language-names to languages
     LanguageCache languageCache; //Maps mimetype-names to languages
-    typedef QMultiHash<QMimeType, ILanguageSupport*> MimeTypeCache;
+    using MimeTypeCache = QMultiHash<QMimeType, ILanguageSupport*>;
     MimeTypeCache mimeTypeCache; //Maps mimetypes to languages
 
     BackgroundParser* const backgroundParser;
@@ -141,7 +133,7 @@ void LanguageControllerPrivate::addLanguageSupport(KDevelop::ILanguageSupport* l
 
 LanguageController::LanguageController(QObject *parent)
     : ILanguageController(parent)
-    , d(new LanguageControllerPrivate(this))
+    , d_ptr(new LanguageControllerPrivate(this))
 {
     setObjectName(QStringLiteral("LanguageController"));
 }
@@ -150,6 +142,8 @@ LanguageController::~LanguageController() = default;
 
 void LanguageController::initialize()
 {
+    Q_D(LanguageController);
+
     d->backgroundParser->loadSettings();
     d->staticAssistantsManager = new StaticAssistantsManager(this);
 
@@ -157,17 +151,21 @@ void LanguageController::initialize()
     DUChain::self();
 
     connect(Core::self()->documentController(), &IDocumentController::documentActivated,
-            this, [&] (IDocument* document) { d->documentActivated(document); });
+            this, [this] (IDocument* document) { Q_D(LanguageController); d->documentActivated(document); });
 }
 
 void LanguageController::cleanup()
 {
+    Q_D(LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
     d->m_cleanedUp = true;
 }
 
 QList<ILanguageSupport*> LanguageController::activeLanguages()
 {
+    Q_D(LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
 
     return d->activeLanguages;
@@ -175,6 +173,8 @@ QList<ILanguageSupport*> LanguageController::activeLanguages()
 
 StaticAssistantsManager* LanguageController::staticAssistantsManager() const
 {
+    Q_D(const LanguageController);
+
     return d->staticAssistantsManager;
 }
 
@@ -185,11 +185,15 @@ ICompletionSettings *LanguageController::completionSettings() const
 
 ProblemModelSet* LanguageController::problemModelSet() const
 {
+    Q_D(const LanguageController);
+
     return d->problemModelSet;
 }
 
 QList<ILanguageSupport*> LanguageController::loadedLanguages() const
 {
+    Q_D(const LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
     QList<ILanguageSupport*> ret;
 
@@ -197,20 +201,24 @@ QList<ILanguageSupport*> LanguageController::loadedLanguages() const
         return ret;
 
     ret.reserve(d->languages.size());
-    foreach(ILanguageSupport* lang, d->languages)
+    for (ILanguageSupport* lang : qAsConst(d->languages)) {
         ret << lang;
+    }
     return ret;
 }
 
 ILanguageSupport* LanguageController::language(const QString &name) const
 {
+    Q_D(const LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
 
     if(d->m_cleanedUp)
         return nullptr;
 
-    if(d->languages.contains(name))
-        return d->languages[name];
+    const auto languageIt = d->languages.constFind(name);
+    if (languageIt != d->languages.constEnd())
+        return *languageIt;
 
     // temporary support for deprecated-in-5.1 "X-KDevelop-Language" as fallback
     // remove in later version
@@ -234,9 +242,9 @@ ILanguageSupport* LanguageController::language(const QString &name) const
     }
 
     if(!supports.isEmpty()) {
-        ILanguageSupport *languageSupport = supports[0]->extension<ILanguageSupport>();
+        auto *languageSupport = supports[0]->extension<ILanguageSupport>();
         if(languageSupport) {
-            d->addLanguageSupport(languageSupport);
+            const_cast<LanguageControllerPrivate*>(d)->addLanguageSupport(languageSupport);
             return languageSupport;
         }
     }
@@ -256,6 +264,8 @@ bool isNumeric(const QString& str)
 
 QList<ILanguageSupport*> LanguageController::languagesForUrl(const QUrl &url)
 {
+    Q_D(LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
 
     QList<ILanguageSupport*> languages;
@@ -271,7 +281,8 @@ QList<ILanguageSupport*> LanguageController::languagesForUrl(const QUrl &url)
     for(LanguageControllerPrivate::MimeTypeCache::const_iterator it = d->mimeTypeCache.constBegin();
         it != d->mimeTypeCache.constEnd(); ++it)
     {
-        foreach(const QString& pattern, it.key().globPatterns()) {
+        const auto globPatterns = it.key().globPatterns();
+        for (const QString& pattern : globPatterns) {
             if(pattern.startsWith(QLatin1Char('*'))) {
                 const QStringRef subPattern = pattern.midRef(1);
                 if (!subPattern.contains(QLatin1Char('*'))) {
@@ -323,6 +334,8 @@ QList<ILanguageSupport*> LanguageController::languagesForUrl(const QUrl &url)
 
 QList<ILanguageSupport*> LanguageController::languagesForMimetype(const QString& mimetype)
 {
+    Q_D(LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
 
     QList<ILanguageSupport*> languages;
@@ -339,7 +352,7 @@ QList<ILanguageSupport*> LanguageController::languagesForMimetype(const QString&
             d->languageCache.insert(mimetype, QList<ILanguageSupport*>());
         } else {
             for (IPlugin *support : supports) {
-                ILanguageSupport* languageSupport = support->extension<ILanguageSupport>();
+                auto* languageSupport = support->extension<ILanguageSupport>();
                 qCDebug(SHELL) << "language-support:" << languageSupport;
                 if(languageSupport) {
                     d->addLanguageSupport(languageSupport);
@@ -353,15 +366,17 @@ QList<ILanguageSupport*> LanguageController::languagesForMimetype(const QString&
 
 QList<QString> LanguageController::mimetypesForLanguageName(const QString& languageName)
 {
+    Q_D(LanguageController);
+
     QMutexLocker lock(&d->dataMutex);
 
     QList<QString> mimetypes;
     for (LanguageCache::ConstIterator iter = d->languageCache.constBegin(); iter != d->languageCache.constEnd(); ++iter) {
-        foreach (ILanguageSupport* language, iter.value()) {
-            if (language->name() == languageName) {
-                mimetypes << iter.key();
-                break;
-            }
+        bool isFromLanguage = std::any_of(iter.value().begin(), iter.value().end(), [&] (ILanguageSupport* language ) {
+            return (language->name() == languageName);
+        });
+        if (isFromLanguage) {
+            mimetypes << iter.key();
         }
     }
     return mimetypes;
@@ -369,11 +384,15 @@ QList<QString> LanguageController::mimetypesForLanguageName(const QString& langu
 
 BackgroundParser *LanguageController::backgroundParser() const
 {
+    Q_D(const LanguageController);
+
     return d->backgroundParser;
 }
 
 void LanguageController::addLanguageSupport(ILanguageSupport* languageSupport, const QStringList& mimetypes)
 {
+    Q_D(LanguageController);
+
     d->addLanguageSupport(languageSupport, mimetypes);
 }
 
