@@ -55,7 +55,8 @@ void WorkingSetController::initialize()
 {
     //Load all working-sets
     KConfigGroup setConfig(Core::self()->activeSession()->config(), "Working File Sets");
-    foreach(const QString& set, setConfig.groupList()) {
+    const auto sets = setConfig.groupList();
+    for (const QString& set : sets) {
         // do not load working set if the id contains an '|', because it then belongs to an area.
         // this is functionally equivalent to the if ( ! config->icon ) stuff which was there before.
         if (set.contains(QLatin1Char('|'))) {
@@ -73,8 +74,10 @@ void WorkingSetController::initialize()
 
 void WorkingSetController::cleanup()
 {
-    foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
-        foreach (Sublime::Area *area, window->areas()) {
+    const auto windows = Core::self()->uiControllerInternal()->mainWindows();
+    for (Sublime::MainWindow* window : windows) {
+        const auto areas = window->areas();
+        for (Sublime::Area* area : areas) {
             if (!area->workingSet().isEmpty()) {
                 Q_ASSERT(m_workingSets.contains(area->workingSet()));
                 m_workingSets[area->workingSet()]->saveFromArea(area, area->rootIndex());
@@ -82,7 +85,8 @@ void WorkingSetController::cleanup()
         }
     }
 
-    foreach(WorkingSet* set, m_workingSets) {
+    const auto oldWorkingSet = m_workingSets;
+    for (WorkingSet* set : oldWorkingSet) {
         qCDebug(SHELL) << "set" << set->id() << "persistent" << set->isPersistent() << "has areas:" << set->hasConnectedAreas() << "files" << set->fileList();
         if(!set->isPersistent() && !set->hasConnectedAreas()) {
             qCDebug(SHELL) << "deleting";
@@ -131,15 +135,16 @@ WorkingSet* WorkingSetController::workingSet(const QString& id)
     if(id.isEmpty())
         return m_emptyWorkingSet;
 
-    if(!m_workingSets.contains(id)) {
-        WorkingSet* set = new WorkingSet(id);
+    auto workingSetIt = m_workingSets.find(id);
+    if (workingSetIt == m_workingSets.end()) {
+        auto* set = new WorkingSet(id);
         connect(set, &WorkingSet::aboutToRemove,
                 this, &WorkingSetController::aboutToRemoveWorkingSet);
-        m_workingSets[id] = set;
+        workingSetIt= m_workingSets.insert(id, set);
         emit workingSetAdded(set);
     }
 
-    return m_workingSets[id];
+    return *workingSetIt;
 }
 
 QWidget* WorkingSetController::createSetManagerWidget(MainWindow* parent, Sublime::Area* fixedArea) {
@@ -163,12 +168,12 @@ void WorkingSetController::showToolTip(WorkingSet* set, const QPoint& pos)
 {
     delete m_tooltip;
 
-    KDevelop::MainWindow* window = static_cast<KDevelop::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow());
+    auto* window = static_cast<KDevelop::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow());
 
     m_tooltip = new KDevelop::ActiveToolTip(window, pos);
-    QVBoxLayout* layout = new QVBoxLayout(m_tooltip);
+    auto* layout = new QVBoxLayout(m_tooltip);
     layout->setMargin(0);
-    WorkingSetToolTipWidget* widget = new WorkingSetToolTipWidget(m_tooltip, set, window);
+    auto* widget = new WorkingSetToolTipWidget(m_tooltip, set, window);
     layout->addWidget(widget);
     m_tooltip->resize( m_tooltip->sizeHint() );
 
@@ -179,7 +184,7 @@ void WorkingSetController::showToolTip(WorkingSet* set, const QPoint& pos)
 
 void WorkingSetController::showGlobalToolTip()
 {
-    KDevelop::MainWindow* window = static_cast<KDevelop::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow());
+    auto* window = static_cast<KDevelop::MainWindow*>(Core::self()->uiControllerInternal()->activeMainWindow());
 
     showToolTip(workingSet(window->area()->workingSet()),
                               window->mapToGlobal(window->geometry().topRight()));
@@ -187,7 +192,7 @@ void WorkingSetController::showGlobalToolTip()
     connect(m_hideToolTipTimer, &QTimer::timeout,  m_tooltip.data(), &ActiveToolTip::deleteLater);
     m_hideToolTipTimer->start();
     connect(m_tooltip.data(), &ActiveToolTip::mouseIn, m_hideToolTipTimer, &QTimer::stop);
-    connect(m_tooltip.data(), &ActiveToolTip::mouseOut, m_hideToolTipTimer, static_cast<void(QTimer::*)()>(&QTimer::start));
+    connect(m_tooltip.data(), &ActiveToolTip::mouseOut, m_hideToolTipTimer, QOverload<>::of(&QTimer::start));
 }
 
 WorkingSetToolTipWidget* WorkingSetController::workingSetToolTip()
@@ -199,7 +204,7 @@ WorkingSetToolTipWidget* WorkingSetController::workingSetToolTip()
 
     if(m_tooltip)
     {
-        WorkingSetToolTipWidget* widget = m_tooltip->findChild<WorkingSetToolTipWidget*>();
+        auto* widget = m_tooltip->findChild<WorkingSetToolTipWidget*>();
         Q_ASSERT(widget);
         return widget;
     }
@@ -284,7 +289,7 @@ void WorkingSetController::changedWorkingSet(Sublime::Area* area, const QString&
 
 void WorkingSetController::viewAdded( Sublime::AreaIndex* , Sublime::View* )
 {
-    Sublime::Area* area = qobject_cast< Sublime::Area* >(sender());
+    auto* area = qobject_cast< Sublime::Area* >(sender());
     Q_ASSERT(area);
 
     if (area->workingSet().isEmpty()) {
