@@ -57,7 +57,11 @@ QIcon generateIcon(const WorkingSetIconParameters& params)
         {9, 9, 5, 5},
     };
     if ( params.swapDiagonal ) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+        rects.swapItemsAt(1, 2);
+#else
         rects.swap(1, 2);
+#endif
     }
 
     QPainter painter(&pixmap);
@@ -88,7 +92,7 @@ QIcon generateIcon(const WorkingSetIconParameters& params)
         brightColor = brightColor.lighter(120 + (params.setId*13) % 55);
     }
     int at = 0;
-    foreach ( const QRect rect, rects ) {
+    for (const QRect& rect : qAsConst(rects)) {
         QColor currentColor;
         // pick the colored squares; you can get different patterns by re-ordering the "rects" list
         if ( (at + params.setId*7) % 4 < coloredCount ) {
@@ -138,7 +142,8 @@ void WorkingSet::saveFromArea( Sublime::Area* a, Sublime::AreaIndex * area, KCon
         setGroup.writeEntry("View Count", area->viewCount());
         areaGroup.writeEntry("View Count", area->viewCount());
         int index = 0;
-        foreach (Sublime::View* view, area->views()) {
+        const auto views = area->views();
+        for (Sublime::View* view : views) {
             //The working set config gets an updated list of files
             QString docSpec = view->document()->documentSpecifier();
 
@@ -169,7 +174,8 @@ struct DisableMainWindowUpdatesFromArea
 {
     explicit DisableMainWindowUpdatesFromArea(Sublime::Area* area) : m_area(area) {
         if(area) {
-            foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
+            const auto windows = Core::self()->uiControllerInternal()->mainWindows();
+            for (Sublime::MainWindow* window : windows) {
                 if(window->area() == area) {
                     if(window->updatesEnabled()) {
                         wasUpdatesEnabled.insert(window);
@@ -182,17 +188,20 @@ struct DisableMainWindowUpdatesFromArea
 
     ~DisableMainWindowUpdatesFromArea() {
         if(m_area) {
-            foreach(Sublime::MainWindow* window, wasUpdatesEnabled) {
+            for (Sublime::MainWindow* window : qAsConst(wasUpdatesEnabled)) {
                 window->setUpdatesEnabled(wasUpdatesEnabled.contains(window));
             }
         }
     }
 
+private:
+    Q_DISABLE_COPY(DisableMainWindowUpdatesFromArea)
+
     Sublime::Area* m_area;
     QSet<Sublime::MainWindow*> wasUpdatesEnabled;
 };
 
-void loadFileList(QStringList& ret, KConfigGroup group)
+void loadFileList(QStringList& ret, const KConfigGroup& group)
 {
     if (group.hasKey("Orientation")) {
         QStringList subgroups = group.groupList();
@@ -244,8 +253,10 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
 
     QMultiMap<QString, Sublime::View*> recycle;
 
-    foreach( Sublime::View* view, area->views() )
+    const auto viewsBefore = area->views();
+    for (Sublime::View* view : viewsBefore) {
         recycle.insert( view->document()->documentSpecifier(), area->removeView(view) );
+    }
 
     qCDebug(SHELL) << "recycling" << recycle.size() << "old views";
 
@@ -266,7 +277,8 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
     //activate view in the working set
     /// @todo correctly select one out of multiple equal views
     QString activeView = areaGroup.readEntry("Active View", QString());
-    foreach (Sublime::View *v, area->views()) {
+    const auto viewsAfter = area->views();
+    for (Sublime::View* v : viewsAfter) {
         if (v->document()->documentSpecifier() == activeView) {
             area->setActiveView(v);
             break;
@@ -277,7 +289,8 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
         area->setActiveView( area->views().at(0) );
 
     if( area->activeView() ) {
-        foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
+        const auto windows = Core::self()->uiControllerInternal()->mainWindows();
+        for (Sublime::MainWindow* window : windows) {
                 if(window->area() == area) {
                     window->activateView( area->activeView() );
                 }
@@ -332,7 +345,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
             }
             IDocument* doc = Core::self()->documentControllerInternal()->openDocument(QUrl::fromUserInput(specifier),
                              KTextEditor::Cursor::invalid(), IDocumentController::DoNotActivate | IDocumentController::DoNotCreateView);
-            Sublime::Document *document = dynamic_cast<Sublime::Document*>(doc);
+            auto *document = dynamic_cast<Sublime::Document*>(doc);
             if (document) {
                 Sublime::View* view = document->createView();
                 area->addView(view, areaIndex, previousView);
@@ -354,12 +367,14 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
 
 void deleteGroupRecursive(KConfigGroup group) {
 //     qCDebug(SHELL) << "deleting" << group.name();
-    foreach(const QString& entry, group.entryMap().keys()) {
-        group.deleteEntry(entry);
+    const auto entryMap = group.entryMap();
+    for (auto it = entryMap.begin(), end = entryMap.end(); it != end; ++it) {
+        group.deleteEntry(it.key());
     }
     Q_ASSERT(group.entryMap().isEmpty());
 
-    foreach(const QString& subGroup, group.groupList()) {
+    const auto groupList = group.groupList();
+    for (const QString& subGroup : groupList) {
         deleteGroupRecursive(group.group(subGroup));
         group.deleteGroup(subGroup);
     }
@@ -422,7 +437,7 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
 }
 
 void WorkingSet::areaViewAdded(Sublime::AreaIndex*, Sublime::View*) {
-    Sublime::Area* area = qobject_cast<Sublime::Area*>(sender());
+    auto* area = qobject_cast<Sublime::Area*>(sender());
     Q_ASSERT(area);
     Q_ASSERT(area->workingSet() == m_id);
 
@@ -436,7 +451,7 @@ void WorkingSet::areaViewAdded(Sublime::AreaIndex*, Sublime::View*) {
 }
 
 void WorkingSet::areaViewRemoved(Sublime::AreaIndex*, Sublime::View* view) {
-    Sublime::Area* area = qobject_cast<Sublime::Area*>(sender());
+    auto* area = qobject_cast<Sublime::Area*>(sender());
     Q_ASSERT(area);
     Q_ASSERT(area->workingSet() == m_id);
 
@@ -446,14 +461,14 @@ void WorkingSet::areaViewRemoved(Sublime::AreaIndex*, Sublime::View* view) {
         return;
     }
 
-    foreach(Sublime::Area* otherArea, m_areas)
-    {
+    const auto areasBefore = m_areas; // TODO: check if areas could be changed, otherwise use m_areas directly
+    for (Sublime::Area* otherArea : areasBefore) {
         if(otherArea == area)
             continue;
-        bool hadDocument = false;
-        foreach(Sublime::View* areaView, otherArea->views())
-            if(view->document() == areaView->document())
-                hadDocument = true;
+        const auto otherAreaViews = otherArea->views();
+        bool hadDocument = std::any_of(otherAreaViews.begin(), otherAreaViews.end(), [&](Sublime::View* otherView) {
+            return (view->document() == otherView->document());
+        });
 
         if(!hadDocument)
         {
