@@ -33,6 +33,7 @@ class Area;
 class AreaIndex;
 class Document;
 class MainWindow;
+class ControllerPrivate;
 
 /**
 @short Handles association of areas to main windows.
@@ -101,7 +102,7 @@ public:
     /** Return the default area with given @p id.*/
     Area *defaultArea(const QString &id) const;
 
-    /** Add a main window to the set of of windows managed by this
+    /** Add a main window to the set of windows managed by this
         controller.  The ownership of the window is passed to the
         controller.  The window will be associated with a set of
         areas created by cloning the current defaultAreas.  */
@@ -188,7 +189,8 @@ private:
     void addDocument(Document *document);
 
 private:
-    const QScopedPointer<class ControllerPrivate> d;
+    const QScopedPointer<class ControllerPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(Controller)
 
     friend class Area;
     friend class Document;
