@@ -62,7 +62,7 @@ ProjectSelectionPage::ProjectSelectionPage(ProjectTemplatesModel *templatesModel
     connect (ui->listView, &MultiLevelListView::currentIndexChanged, this, &ProjectSelectionPage::typeChanged);
     typeChanged(ui->listView->currentIndex());
 
-    connect( ui->templateType, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+    connect( ui->templateType, QOverload<int>::of(&QComboBox::currentIndexChanged),
              this, &ProjectSelectionPage::templateChanged );
 
     QPushButton* getMoreButton = new QPushButton(i18n("Get More Templates"), ui->listView);
@@ -71,7 +71,7 @@ ProjectSelectionPage::ProjectSelectionPage(ProjectTemplatesModel *templatesModel
              this, &ProjectSelectionPage::moreTemplatesClicked);
     ui->listView->addWidget(0, getMoreButton);
 
-    QPushButton* loadButton = new QPushButton(ui->listView);
+    auto* loadButton = new QPushButton(ui->listView);
     loadButton->setText(i18n("Load Template From File"));
     loadButton->setIcon(QIcon::fromTheme(QStringLiteral("application-x-archive")));
     connect (loadButton, &QPushButton::clicked, this, &ProjectSelectionPage::loadFileClicked);
@@ -273,8 +273,8 @@ QStandardItem* ProjectSelectionPage::currentItem() const
     QStandardItem* item = m_templatesModel->itemFromIndex( ui->listView->currentIndex() );
     if ( item && item->hasChildren() )
     {
-        const int currect = ui->templateType->currentIndex();
-        const QModelIndex idx = m_templatesModel->index( currect, 0, ui->templateType->rootModelIndex() );
+        const int current = ui->templateType->currentIndex();
+        const QModelIndex idx = m_templatesModel->index( current, 0, ui->templateType->rootModelIndex() );
         item = m_templatesModel->itemFromIndex(idx);
     }
     return item;
