@@ -172,6 +172,10 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
         m_environment.addFrameworkDirectories(IDefinesAndIncludesManager::manager()->frameworkDirectories(file));
         m_environment.addDefines(IDefinesAndIncludesManager::manager()->defines(file));
         m_environment.setParserSettings(ClangSettingsManager::self()->parserSettings(file));
+        if (hasBuildSystemInfo) {
+            // Assume the builder invokes the compiler in the build directory.
+            m_environment.setWorkingDirectory(file->project()->buildSystemManager()->buildDirectory(file));
+        }
     } else {
         m_environment.addIncludes(IDefinesAndIncludesManager::manager()->includes(tuUrl.str()));
         m_environment.addFrameworkDirectories(IDefinesAndIncludesManager::manager()->frameworkDirectories(tuUrl.str()));
@@ -195,7 +199,8 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
 
     m_unsavedFiles = ClangUtils::unsavedFiles();
 
-    foreach(auto document, ICore::self()->documentController()->openDocuments()) {
+    const auto documents = ICore::self()->documentController()->openDocuments();
+    for (auto* document : documents) {
         auto textDocument = document->textDocument();
         if ( !textDocument ) {
             continue;
@@ -237,6 +242,7 @@ void ClangParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*
         m_environment.addIncludes(IDefinesAndIncludesManager::manager()->includesInBackground(tuUrlStr));
         m_environment.addFrameworkDirectories(IDefinesAndIncludesManager::manager()->frameworkDirectoriesInBackground(tuUrlStr));
         m_environment.addDefines(IDefinesAndIncludesManager::manager()->definesInBackground(tuUrlStr));
+        m_environment.addParserArguments(IDefinesAndIncludesManager::manager()->parserArgumentsInBackground(tuUrlStr));
         m_environment.setPchInclude(userDefinedPchIncludeForFile(tuUrlStr));
     }
 
@@ -345,7 +351,7 @@ void ClangParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*
 #endif
     }
 
-    foreach(const auto& context, includedFiles) {
+    for (const auto& context : qAsConst(includedFiles)) {
         if (!context) {
             continue;
         }
