@@ -52,7 +52,7 @@
 #include "duchain/clangparsingenvironment.h"
 #include "duchain/parsesession.h"
 
-#include <custom-definesandincludes/idefinesandincludesmanager.h>
+#include "testprovider.h"
 
 #include <KConfigGroup>
 
@@ -65,34 +65,6 @@ QTEST_MAIN(TestDUChain)
 
 using namespace KDevelop;
 
-class TestEnvironmentProvider final : public IDefinesAndIncludesManager::BackgroundProvider
-{
-public:
-    ~TestEnvironmentProvider() override = default;
-    QHash< QString, QString > definesInBackground(const QString& /*path*/) const override
-    {
-        return defines;
-    }
-
-    Path::List includesInBackground(const QString& /*path*/) const override
-    {
-        return includes;
-    }
-
-    Path::List frameworkDirectoriesInBackground(const QString&) const override
-    {
-        return {};
-    }
-
-    IDefinesAndIncludesManager::Type type() const override
-    {
-        return IDefinesAndIncludesManager::UserDefined;
-    }
-
-    QHash<QString, QString> defines;
-    Path::List includes;
-};
-
 TestDUChain::~TestDUChain() = default;
 
 void TestDUChain::initTestCase()
@@ -1229,13 +1201,13 @@ void TestDUChain::testMacroDependentHeader()
     QCOMPARE(top->localDeclarations().size(), 10); // 2x macro, then a, aq, b, bq
     QCOMPARE(top->importedParentContexts().size(), 1);
     AbstractType::Ptr type = top->localDeclarations()[2]->abstractType();
-    StructureType* sType = dynamic_cast<StructureType*>(type.data());
+    auto* sType = dynamic_cast<StructureType*>(type.data());
     QVERIFY(sType);
     QCOMPARE(sType->toString(), QString("A"));
     Declaration* decl = sType->declaration(top);
     QVERIFY(decl);
     AbstractType::Ptr type2 = top->localDeclarations()[4]->abstractType();
-    StructureType* sType2 = dynamic_cast<StructureType*>(type2.data());
+    auto* sType2 = dynamic_cast<StructureType*>(type2.data());
     QVERIFY(sType2);
     QCOMPARE(sType2->toString(), QString("B"));
     Declaration* decl2 = sType2->declaration(top);
@@ -1283,11 +1255,11 @@ void TestDUChain::testHeaderParsingOrder1()
     QCOMPARE(top->localDeclarations().size(), 2);
     QCOMPARE(top->importedParentContexts().size(), 1);
     AbstractType::Ptr type = top->localDeclarations()[1]->abstractType();
-    TypeAliasType* aType = dynamic_cast<TypeAliasType*>(type.data());
+    auto* aType = dynamic_cast<TypeAliasType*>(type.data());
     QVERIFY(aType);
     AbstractType::Ptr targetType = aType->type();
     QVERIFY(targetType);
-    IdentifiedType *idType = dynamic_cast<IdentifiedType*>(targetType.data());
+    auto *idType = dynamic_cast<IdentifiedType*>(targetType.data());
     QVERIFY(idType);
     // this declaration could be resolved, because it was created with an
     // indirect DeclarationId that is resolved from the perspective of 'top'
@@ -1323,11 +1295,11 @@ void TestDUChain::testHeaderParsingOrder2()
     QCOMPARE(top->localDeclarations().size(), 1);
     QCOMPARE(top->importedParentContexts().size(), 2);
     AbstractType::Ptr type = top->localDeclarations()[0]->abstractType();
-    TypeAliasType* aType = dynamic_cast<TypeAliasType*>(type.data());
+    auto* aType = dynamic_cast<TypeAliasType*>(type.data());
     QVERIFY(aType);
     AbstractType::Ptr targetType = aType->type();
     QVERIFY(targetType);
-    IdentifiedType *idType = dynamic_cast<IdentifiedType*>(targetType.data());
+    auto *idType = dynamic_cast<IdentifiedType*>(targetType.data());
     QVERIFY(idType);
     Declaration* decl = idType->declaration(top);
     // NOTE: the decl. doesn't know (yet) about the template insantiation <int>
@@ -1930,6 +1902,129 @@ void TestDUChain::testVariadicTemplateArguments()
     }
 }
 
+void TestDUChain::testProblemRequestedHere()
+{
+    auto headerCode = QStringLiteral(R"(
+#pragma once
+
+template <typename T>
+T AddObjects(const T& a, const T& b)
+{
+  return a + b;
+}
+    )");
+    TestFile header(headerCode, QStringLiteral("h"));
+
+    QString sourceCode = QStringLiteral(R"(
+#include "%1"
+struct A {};
+
+int main()
+{
+    A a, b;
+    AddObjects(a, b);
+    return 0;
+}
+    )").arg(header.url().str());
+    TestFile impl(sourceCode, QStringLiteral("cpp"), &header);
+    QVERIFY(impl.parseAndWait(TopDUContext::AllDeclarationsContextsAndUses));
+
+    DUChainReadLocker lock;
+
+    auto top = impl.topContext();
+    QVERIFY(top);
+
+    auto* headerCtx = dynamic_cast<TopDUContext*>(top->importedParentContexts().first().context(top));
+    QVERIFY(headerCtx);
+    QCOMPARE(headerCtx->url(), header.url());
+
+    QCOMPARE(headerCtx->problems().count(), 1);
+    QCOMPARE(headerCtx->localDeclarations().count(), 1);
+
+    // Verify that the problem is reported for the source file.
+    QCOMPARE(top->problems().count(), 1);
+    QCOMPARE(top->localDeclarations().count(), 2);
+}
+
+void TestDUChain::testProblemRequestedHereSameFile()
+{
+    auto sourceCode = QStringLiteral(R"(
+struct A {};
+
+template <typename T>
+T AddObjects(const T& a, const T& b)
+{
+  return a + b;
+}
+
+int main()
+{
+    A a, b;
+    AddObjects(a, b);
+    return 0;
+}
+    )");
+    TestFile impl(sourceCode, QStringLiteral("cpp"));
+    QVERIFY(impl.parseAndWait(TopDUContext::AllDeclarationsContextsAndUses));
+
+    DUChainReadLocker lock;
+
+    auto top = impl.topContext();
+    QVERIFY(top);
+
+    QCOMPARE(top->problems().count(), 2);
+}
+
+void TestDUChain::testProblemRequestedHereChain()
+{
+    auto headerCode = QStringLiteral(R"(
+#pragma once
+
+template <typename T>
+T AddObjects(const T& a, const T& b)
+{
+  return a + b;
+}
+    )");
+    TestFile header(headerCode, QStringLiteral("h"));
+
+    QString sourceCode = QStringLiteral(R"(
+#include "%1"
+struct A {};
+
+template <typename T>
+T AddObjects2(const T& a, const T& b)
+{
+  return AddObjects(a, b);
+}
+
+int main()
+{
+    A a, b;
+    AddObjects2(a, b);
+    return 0;
+}
+    )").arg(header.url().str());
+    TestFile impl(sourceCode, QStringLiteral("cpp"), &header);
+    QVERIFY(impl.parseAndWait(TopDUContext::AllDeclarationsContextsAndUses));
+
+    DUChainReadLocker lock;
+
+    auto top = impl.topContext();
+    QVERIFY(top);
+
+    auto* headerCtx = dynamic_cast<TopDUContext*>(top->importedParentContexts().first().context(top));
+    QVERIFY(headerCtx);
+    QCOMPARE(headerCtx->url(), header.url());
+
+    QCOMPARE(headerCtx->problems().count(), 1);
+    QCOMPARE(headerCtx->localDeclarations().count(), 1);
+
+    // Verify that the problem is reported for the source file.
+    QCOMPARE(top->problems().count(), 2);
+    QCOMPARE(top->localDeclarations().count(), 3);
+}
+
 void TestDUChain::testGccCompatibility()
 {
     // TODO: make it easier to change the compiler provider for testing purposes
