@@ -54,7 +54,7 @@ bool isFunction(const Declaration* decl)
     return decl->abstractType().cast<FunctionType>();
 }
 
-bool isPathChar(const QChar& c)
+bool isPathChar(QChar c)
 {
     return c.isLetterOrNumber() || c == QLatin1Char('/') || c == QLatin1Char('.');
 }
@@ -93,7 +93,7 @@ void CMakeCodeCompletionModel::completionInvoked(View* view, const Range& range,
     for(int l=range.end().line(); l>=0 && !m_inside; --l)
     {
         QString cline=d->line(l);
-        QString line=cline.left(cline.indexOf(QLatin1Char('#')));
+        const QStringRef line = cline.leftRef(cline.indexOf(QLatin1Char('#')));
         
         int close=line.lastIndexOf(QLatin1Char(')')), open=line.indexOf(QLatin1Char('('));
         
@@ -120,10 +120,9 @@ void CMakeCodeCompletionModel::completionInvoked(View* view, const Range& range,
         
         int lastdir=tocomplete.lastIndexOf(QLatin1Char('/'));
         QString path = KIO::upUrl(QUrl(d->url())).adjusted(QUrl::StripTrailingSlash).toLocalFile()+QLatin1Char('/');
-        QString basePath;
         if(lastdir>=0) {
-            basePath=tocomplete.mid(0, lastdir);
-            path+=basePath;
+            const QStringRef basePath = tocomplete.midRef(0, lastdir);
+            path += basePath;
         }
         QDir dir(path);
         
