@@ -81,7 +81,7 @@ static const QString buildDirPathKey = QStringLiteral("Build Directory Path");
 // Support the old "CMake Binary" key too for backwards compatibility during
 // a reasonable transition period. Both keys are saved at least until 5.2.0
 // is released. Import support for the old key will need to remain for a
-// considably longer period, ideally.
+// considerably longer period, ideally.
 static const QString cmakeBinaryKey = QStringLiteral("CMake Binary");
 static const QString cmakeExecutableKey = QStringLiteral("CMake Executable");
 static const QString cmakeBuildTypeKey = QStringLiteral("Build Type");
@@ -198,14 +198,45 @@ KDevelop::Path::List resolveSystemDirs(KDevelop::IProject* project, const QStrin
 ///NOTE: when you change this, update @c defaultConfigure in cmakemanagertest.cpp
 bool checkForNeedingConfigure( KDevelop::IProject* project )
 {
-    const QString currentRuntime = ICore::self()->runtimeController()->currentRuntime()->name();
+    auto currentRuntime = ICore::self()->runtimeController()->currentRuntime();
+    const QString currentRuntimeName = currentRuntime->name();
     const KDevelop::Path builddir = currentBuildDir(project);
-    const bool isValid = (buildDirRuntime(project, -1) == currentRuntime || buildDirRuntime(project, -1).isEmpty()) && builddir.isValid();
+    const bool isValid = (buildDirRuntime(project, -1) == currentRuntimeName || buildDirRuntime(project, -1).isEmpty()) && builddir.isValid();
 
     if( !isValid )
     {
-        CMakeBuildDirChooser bd;
+        auto addBuildDir = [project](const KDevelop::Path& buildFolder, const KDevelop::Path& installPrefix, const QString &extraArguments, const QString &buildType, const KDevelop::Path &cmakeExecutable){
+            int addedBuildDirIndex = buildDirCount( project ); // old count is the new index
 
+            // Initialize the kconfig items with the values from the dialog, this ensures the settings
+            // end up in the config file once the changes are saved
+            qCDebug(CMAKE) << "adding to cmake config: new builddir index" << addedBuildDirIndex;
+            qCDebug(CMAKE) << "adding to cmake config: builddir path " << buildFolder;
+            qCDebug(CMAKE) << "adding to cmake config: installdir " << installPrefix;
+            qCDebug(CMAKE) << "adding to cmake config: extra args" << extraArguments;
+            qCDebug(CMAKE) << "adding to cmake config: build type " << buildType;
+            qCDebug(CMAKE) << "adding to cmake config: cmake executable " << cmakeExecutable;
+            qCDebug(CMAKE) << "adding to cmake config: environment <null>";
+            CMake::setBuildDirCount( project, addedBuildDirIndex + 1 );
+            CMake::setCurrentBuildDirIndex( project, addedBuildDirIndex );
+            CMake::setCurrentBuildDir( project, buildFolder );
+            CMake::setCurrentInstallDir( project, installPrefix );
+            CMake::setCurrentExtraArguments( project, extraArguments );
+            CMake::setCurrentBuildType( project, buildType );
+            CMake::setCurrentCMakeExecutable(project, cmakeExecutable );
+            CMake::setCurrentEnvironment( project, QString() );
+        };
+
+        if (!currentRuntime->buildPath().isEmpty()) {
+            const Path newBuilddir(currentRuntime->buildPath(), QStringLiteral("build-") + currentRuntimeName + project->name());
+            const Path installPath(QString::fromUtf8(currentRuntime->getenv("KDEV_DEFAULT_INSTALL_PREFIX")));
+
+            addBuildDir(newBuilddir, installPath, {}, QStringLiteral("Debug"), {});
+            setBuildDirRuntime( project, currentRuntimeName );
+            return true;
+        }
+
+        CMakeBuildDirChooser bd;
         bd.setProject( project );
         const auto builddirs = CMake::allBuildDirs(project);
         bd.setAlreadyUsed( builddirs );
@@ -223,27 +254,9 @@ bool checkForNeedingConfigure( KDevelop::IProject* project )
         }
         else
         {
-            int addedBuildDirIndex = buildDirCount( project ); // old count is the new index
-
-            // Initialize the kconfig items with the values from the dialog, this ensures the settings
-            // end up in the config file once the changes are saved
-            qCDebug(CMAKE) << "adding to cmake config: new builddir index" << addedBuildDirIndex;
-            qCDebug(CMAKE) << "adding to cmake config: builddir path " << bd.buildFolder();
-            qCDebug(CMAKE) << "adding to cmake config: installdir " << bd.installPrefix();
-            qCDebug(CMAKE) << "adding to cmake config: extra args" << bd.extraArguments();
-            qCDebug(CMAKE) << "adding to cmake config: build type " << bd.buildType();
-            qCDebug(CMAKE) << "adding to cmake config: cmake executable " << bd.cmakeExecutable();
-            qCDebug(CMAKE) << "adding to cmake config: environment <null>";
-            CMake::setBuildDirCount( project, addedBuildDirIndex + 1 );
-            CMake::setCurrentBuildDirIndex( project, addedBuildDirIndex );
-            CMake::setCurrentBuildDir( project, bd.buildFolder() );
-            CMake::setCurrentInstallDir( project, bd.installPrefix() );
-            CMake::setCurrentExtraArguments( project, bd.extraArguments() );
-            CMake::setCurrentBuildType( project, bd.buildType() );
-            CMake::setCurrentCMakeExecutable(project, bd.cmakeExecutable());
-            CMake::setCurrentEnvironment( project, QString() );
+            addBuildDir(bd.buildFolder(), bd.installPrefix(), bd.extraArguments(), bd.buildType(), bd.cmakeExecutable());
         }
-        setBuildDirRuntime( project, currentRuntime );
+        setBuildDirRuntime( project, currentRuntimeName );
 
         return true;
     } else if( !QFile::exists( KDevelop::Path(builddir, QStringLiteral("CMakeCache.txt")).toLocalFile() ) ||
@@ -252,10 +265,10 @@ bool checkForNeedingConfigure( KDevelop::IProject* project )
                     QFile::exists( KDevelop::Path(builddir, QStringLiteral("build.ninja")).toLocalFile() ) ) )
     {
         // User entered information already, but cmake hasn't actually been run yet.
-        setBuildDirRuntime( project, currentRuntime );
+        setBuildDirRuntime( project, currentRuntimeName );
         return true;
     }
-    setBuildDirRuntime( project, currentRuntime );
+    setBuildDirRuntime( project, currentRuntimeName );
     return false;
 }
 
@@ -678,15 +691,15 @@ QString defaultGenerator()
     return defGen;
 }
 
-QVector<Test> importTestSuites(const Path &buildDir)
+QVector<Test> importTestSuites(const Path &buildDir, const QString &cmakeTestFileName)
 {
-    const auto contents = CMakeListsParser::readCMakeFile(buildDir.toLocalFile() + QLatin1String("/CTestTestfile.cmake"));
-
+    const auto cmakeTestFile = Path(buildDir, cmakeTestFileName).toLocalFile()  ;
+    const auto contents = CMakeListsParser::readCMakeFile(cmakeTestFile);
+    
     QVector<Test> tests;
     for (const auto& entry: contents) {
         if (entry.name == QLatin1String("add_test")) {
             auto args = entry.arguments;
-
             Test test;
             test.name = args.takeFirst().value;
             test.executable = args.takeFirst().value;
@@ -694,6 +707,9 @@ QVector<Test> importTestSuites(const Path &buildDir)
             tests += test;
         } else if (entry.name == QLatin1String("subdirs")) {
             tests += importTestSuites(Path(buildDir, entry.arguments.first().value));
+        } else if (entry.name == QLatin1String("include")) {
+            // Include directive points directly to a .cmake file hosting the tests
+            tests += importTestSuites(Path(buildDir, entry.arguments.first().value), QString());
         } else if (entry.name == QLatin1String("set_tests_properties")) {
             if(entry.arguments.count() < 4 || entry.arguments.count() % 2) {
                 qCWarning(CMAKE) << "found set_tests_properties() with unexpected number of arguments:"
@@ -719,4 +735,8 @@ QVector<Test> importTestSuites(const Path &buildDir)
     return tests;
 }
 
+QVector<Test> importTestSuites(const Path &buildDir) {
+    return importTestSuites(buildDir, QStringLiteral("CTestTestfile.cmake"));
+}
+
 }
