@@ -47,8 +47,8 @@ Declaration* findTestClassDeclaration(const CursorInRevision& c, DUContext* ctx,
      * or range.
      */
 
-    foreach(DUContext* subCtx, ctx->childContexts())
-    {
+    const auto subContexts = ctx->childContexts();
+    for (DUContext* subCtx : subContexts) {
         //This is a little hacky, but we need it in case of foreach macros and similar stuff
         if(subCtx->range().contains(c, behavior) || subCtx->range().isEmpty() || subCtx->range().start.line == c.line || subCtx->range().end.line == c.line)
         {
@@ -101,17 +101,16 @@ void CTestSuite::loadDeclarations(const IndexedString& document, const KDevelop:
     }
 
     Declaration* testClass = nullptr;
-    Identifier testCaseIdentifier(QStringLiteral("tc"));
 
     const auto mainId = Identifier(QStringLiteral("main"));
-    foreach (Declaration* declaration, topContext->findLocalDeclarations(mainId))
-    {
+    const auto mainDeclarations = topContext->findLocalDeclarations(mainId);
+    for (Declaration* declaration : mainDeclarations) {
         if (declaration->isDefinition())
         {
             qCDebug(CMAKE) << "Found a definition for a function 'main()' at" << declaration->range();
 
             /*
-             * This is a rather hacky soluction to get the test class for a Qt test.
+             * This is a rather hacky solution to get the test class for a Qt test.
              *
              * The class is used as the argument to the QTEST_MAIN or QTEST_GUILESS_MAIN macro.
              * This macro expands to a main() function with a variable declaration with 'tc' as
@@ -171,10 +170,10 @@ void CTestSuite::loadDeclarations(const IndexedString& document, const KDevelop:
         m_suiteDeclaration = IndexedDeclaration(testClass);
     }
 
-    foreach (Declaration* decl, testClass->internalContext()->localDeclarations(topContext))
-    {
+    const auto testClassDeclarations = testClass->internalContext()->localDeclarations(topContext);
+    for (Declaration* decl : testClassDeclarations) {
         qCDebug(CMAKE) << "Found declaration" << decl->toString() << decl->identifier().identifier().byteArray();
-        if (ClassFunctionDeclaration* function = dynamic_cast<ClassFunctionDeclaration*>(decl))
+        if (auto* function = dynamic_cast<ClassFunctionDeclaration*>(decl))
         {
             if (function->accessPolicy() == Declaration::Private && function->isSlot())
             {
