@@ -49,7 +49,8 @@ void IRegisterController::updateRegisters(const GroupsName& group)
     }
 
     if (group.name().isEmpty()) {
-        foreach (const GroupsName & g, namesOfRegisterGroups()) {
+        const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+        for (const GroupsName& g : namesOfRegisterGroups) {
             IRegisterController::updateRegisters(g);
         }
         return;
@@ -93,7 +94,8 @@ void IRegisterController::updateRegisters(const GroupsName& group)
     if (group.type() == flag) {
         registers += numberForName(group.flagName());
     } else {
-        foreach (const QString & name, registerNamesForGroup(group)) {
+        const auto names = registerNamesForGroup(group);
+        for (const QString& name : names) {
             registers += numberForName(name) + QLatin1Char(' ');
         }
     }
@@ -152,9 +154,10 @@ void IRegisterController::generalRegistersHandler(const ResultRecord& r)
 
     GroupsName group = groupForRegisterName(registerName);
 
-    if (m_pendingGroups.contains(group)) {
+    const int groupIndex = m_pendingGroups.indexOf(group);
+    if (groupIndex != -1) {
         emit registersChanged(registersFromGroup(group));
-        m_pendingGroups.remove(m_pendingGroups.indexOf(group));
+        m_pendingGroups.remove(groupIndex);
     }
 }
 
@@ -172,8 +175,9 @@ QString IRegisterController::registerValue(const QString& name) const
 {
     QString value;
     if (!name.isEmpty()) {
-        if (m_registers.contains(name)) {
-            value = m_registers.value(name);
+        const auto registerIt = m_registers.find(name);
+        if (registerIt != m_registers.end()) {
+            value = *registerIt;
         }
     }
     return value;
@@ -191,7 +195,8 @@ bool IRegisterController::initializeRegisters()
 
 GroupsName IRegisterController::groupForRegisterName(const QString& name) const
 {
-    foreach (const GroupsName & group, namesOfRegisterGroups()) {
+    const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+    for (const GroupsName& group : namesOfRegisterGroups) {
         const QStringList registersInGroup = registerNamesForGroup(group);
         if (group.flagName() == name) {
             return group;
@@ -210,8 +215,10 @@ void IRegisterController::updateValuesForRegisters(RegistersGroup* registers) co
     Q_ASSERT(!m_registers.isEmpty());
 
     for (int i = 0; i < registers->registers.size(); i++) {
-        if (m_registers.contains(registers->registers[i].name)) {
-            registers->registers[i].value = m_registers.value(registers->registers[i].name);
+        auto& reg = registers->registers[i];
+        const auto registerIt = m_registers.find(reg.name);
+        if (registerIt != m_registers.end()) {
+            reg.value = *registerIt;
         }
     }
 }
@@ -261,7 +268,8 @@ void IRegisterController::updateFlagValues(RegistersGroup* flagsGroup, const Fla
 QVector<Format> IRegisterController::formats(const GroupsName& group)
 {
     int idx = -1;
-    foreach (const GroupsName & g, namesOfRegisterGroups()) {
+    const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+    for (const GroupsName& g : namesOfRegisterGroups) {
         if (g == group) {
             idx = g.index();
         }
@@ -277,7 +285,8 @@ GroupsName IRegisterController::createGroupName(const QString& name, int idx, Re
 
 void IRegisterController::setFormat(Format f, const GroupsName& group)
 {
-    foreach (const GroupsName & g, namesOfRegisterGroups()) {
+    const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+    for (const GroupsName& g : namesOfRegisterGroups) {
         if (g == group) {
             int i = m_formatsModes[g.index()].formats.indexOf(f);
             if (i != -1) {
@@ -373,16 +382,18 @@ void IRegisterController::structuredRegistersHandler(const ResultRecord& r)
         m_registers.insert(registerName, value);
     }
 
-    if (m_pendingGroups.contains(group)) {
+    const int groupIndex = m_pendingGroups.indexOf(group);
+    if (groupIndex != -1) {
         emit registersChanged(registersFromGroup(group));
-        m_pendingGroups.remove(m_pendingGroups.indexOf(group));
+        m_pendingGroups.remove(groupIndex);
     }
 }
 
 QVector< Mode > IRegisterController::modes(const GroupsName& group)
 {
     int idx = -1;
-    foreach (const GroupsName & g, namesOfRegisterGroups()) {
+    const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+    for (const GroupsName& g : namesOfRegisterGroups) {
         if (g == group) {
             idx = g.index();
         }
@@ -393,7 +404,8 @@ QVector< Mode > IRegisterController::modes(const GroupsName& group)
 
 void IRegisterController::setMode(Mode m, const GroupsName& group)
 {
-    foreach (const GroupsName & g, namesOfRegisterGroups()) {
+    const auto namesOfRegisterGroups = this->namesOfRegisterGroups();
+    for (const GroupsName& g : namesOfRegisterGroups) {
         if (g == group) {
             int i = m_formatsModes[g.index()].modes.indexOf(m);
             if (i != -1) {
