@@ -41,5 +41,5 @@ void {{ name }}::{{ case }}()
 
 {% endfor %}
 
-QTEST_MAIN({{ name }});
-#include "{{ output_file_header|cut:".h" }}.moc"
\ No newline at end of file
+QTEST_MAIN({{ name }})
+#include "{{ output_file_header|cut:".h" }}.moc"
