@@ -146,7 +146,8 @@ void DebugSession::configInferior(ILaunchConfiguration *cfg, IExecutePlugin *iex
     if (breakOnStart) {
         BreakpointModel* m = ICore::self()->debugController()->breakpointModel();
         bool found = false;
-        foreach (Breakpoint *b, m->breakpoints()) {
+        const auto breakpoints = m->breakpoints();
+        for (Breakpoint* b : breakpoints) {
             if (b->location() == QLatin1String("main")) {
                 found = true;
                 break;
@@ -210,7 +211,7 @@ bool DebugSession::execInferior(KDevelop::ILaunchConfiguration *cfg, IExecutePlu
         QByteArray tty(m_tty->getSlave().toLatin1());
         QByteArray options = QByteArray(">") + tty + QByteArray("  2>&1 <") + tty;
 
-        QProcess *proc = new QProcess;
+        auto *proc = new QProcess;
         const QStringList arguments{
             QStringLiteral("-c"),
             KShell::quoteArg(runShellScript.toLocalFile()) + QLatin1Char(' ') + KShell::quoteArg(executable) + QString::fromLatin1(options),
