@@ -53,7 +53,8 @@ ProjectFilterProvider::ProjectFilterProvider( QObject* parent, const QVariantLis
             this, &ProjectFilterProvider::projectAboutToBeOpened);
 
     // initialize the filters for each project
-    foreach(IProject* project, core()->projectController()->projects()) {
+    const auto projects = core()->projectController()->projects();
+    for (IProject* project : projects) {
         updateProjectFilters(project);
     }
 }
@@ -70,7 +71,7 @@ ContextMenuExtension ProjectFilterProvider::contextMenuExtension(Context* contex
         return ret;
     }
 
-    ProjectItemContext* ctx = static_cast<ProjectItemContext*>( context );
+    auto* ctx = static_cast<ProjectItemContext*>( context );
 
     QList<ProjectBaseItem*> items = ctx->items();
     // filter out project roots and items in targets
@@ -98,15 +99,16 @@ ContextMenuExtension ProjectFilterProvider::contextMenuExtension(Context* contex
 
 void ProjectFilterProvider::addFilterFromContextMenu()
 {
-    QAction* action = qobject_cast<QAction*>(sender());
+    auto* action = qobject_cast<QAction*>(sender());
     Q_ASSERT(action);
     const QList<ProjectBaseItem*> items = action->data().value<QList<ProjectBaseItem*>>();
     QHash<IProject*, SerializedFilters> changedProjectFilters;
     for (ProjectBaseItem* item : items) {
-        if (!changedProjectFilters.contains(item->project())) {
-            changedProjectFilters[item->project()] = readFilters(item->project()->projectConfiguration());
+        auto filterIt = changedProjectFilters.find(item->project());
+        if (filterIt == changedProjectFilters.end()) {
+            filterIt = changedProjectFilters.insert(item->project(), readFilters(item->project()->projectConfiguration()));
         }
-        SerializedFilters& filters = changedProjectFilters[item->project()];
+        SerializedFilters& filters = *filterIt;
         Path path;
         if (item->target()) {
             path = Path(item->parent()->path(), item->text());
