@@ -45,7 +45,7 @@
 
 using namespace KDevelop;
 
-typedef QPair<Declaration*, int> DeclarationDepthPair;
+using DeclarationDepthPair = QPair<Declaration*, int>;
 
 namespace QmlJS {
 
@@ -314,7 +314,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionsFromImports(C
             continue;
         }
 
-        NamespaceAliasDeclaration* decl = static_cast<NamespaceAliasDeclaration *>(import);
+        auto* decl = static_cast<NamespaceAliasDeclaration *>(import);
         realImports << m_duContext->findDeclarations(decl->importIdentifier());
     }
 
@@ -370,7 +370,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionsInContext(con
                        ) && decl.second != 0 && decl.second != 1001) {
                 // Only show the local declarations of modules, or the declarations
                 // immediately in its imported parent contexts (that are global
-                // contexts, hence the distance of 1001). This prevens "String()",
+                // contexts, hence the distance of 1001). This prevents "String()",
                 // "QtQuick1.0" and "builtins" from being listed when the user
                 // types "PlasmaCore.".
                 continue;
@@ -380,7 +380,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionsInContext(con
                 // Decorate function calls with brackets
                 decorationOfThisItem = CompletionItem::Brackets;
             } else if (flags.testFlag(CompletionHideWrappers)) {
-                ClassDeclaration* classDecl = dynamic_cast<ClassDeclaration*>(declaration.data());
+                auto* classDecl = dynamic_cast<ClassDeclaration*>(declaration.data());
 
                 if (classDecl && classDecl->classType() == ClassDeclarationData::Interface) {
                     continue;
