@@ -55,7 +55,7 @@ ExpandingWidgetModel::~ExpandingWidgetModel()
 
 static QColor doAlternate(const QColor& color)
 {
-    QColor background = QApplication::palette().background().color();
+    QColor background = QApplication::palette().window().color();
     return KColorUtils::mix(color, background, 0.15);
 }
 
@@ -148,7 +148,7 @@ void ExpandingWidgetModel::clearExpanding()
 {
     clearMatchQualities();
     QMap<QModelIndex, ExpandingWidgetModel::ExpandingType> oldExpandState = m_expandState;
-    foreach (QPointer<QWidget> widget, m_expandingWidgets) {
+    for (auto& widget : qAsConst(m_expandingWidgets)) {
         delete widget;
     }
 
@@ -165,8 +165,9 @@ void ExpandingWidgetModel::clearExpanding()
 
 ExpandingWidgetModel::ExpansionType ExpandingWidgetModel::isPartiallyExpanded(const QModelIndex& index) const
 {
-    if (m_partiallyExpanded.contains(firstColumn(index))) {
-        return m_partiallyExpanded[firstColumn(index)];
+    const auto expansionIt = m_partiallyExpanded.find(firstColumn(index));
+    if (expansionIt != m_partiallyExpanded.end()) {
+        return *expansionIt;
     } else {
         return NotExpanded;
     }
@@ -336,15 +337,16 @@ bool ExpandingWidgetModel::isExpandable(const QModelIndex& idx_) const
 
     QModelIndex idx(firstColumn(idx_));
 
-    if (!m_expandState.contains(idx)) {
-        m_expandState.insert(idx, NotExpandable);
+    auto expandStateIt = m_expandState.find(idx);
+    if (expandStateIt == m_expandState.end()) {
+        expandStateIt = m_expandState.insert(idx, NotExpandable);
         QVariant v = data(idx, CodeCompletionModel::IsExpandable);
         if (v.canConvert<bool>() && v.toBool()) {
-            m_expandState[idx] = Expandable;
+            *expandStateIt = Expandable;
         }
     }
 
-    return m_expandState[idx] != NotExpandable;
+    return *expandStateIt != NotExpandable;
 }
 
 bool ExpandingWidgetModel::isExpanded(const QModelIndex& idx_) const
@@ -411,7 +413,7 @@ int ExpandingWidgetModel::basicRowHeight(const QModelIndex& idx_) const
 
     QModelIndex idx(firstColumn(idx_));
 
-    ExpandingDelegate* delegate = dynamic_cast<ExpandingDelegate*>(treeView()->itemDelegate(idx));
+    auto* delegate = qobject_cast<ExpandingDelegate*>(treeView()->itemDelegate(idx));
     if (!delegate || !idx.isValid()) {
         qCDebug(PLUGIN_QUICKOPEN) << "ExpandingWidgetModel::basicRowHeight: Could not get delegate";
         return 15;
@@ -426,8 +428,9 @@ void ExpandingWidgetModel::placeExpandingWidget(const QModelIndex& idx_)
     QModelIndex idx(firstColumn(idx_));
 
     QWidget* w = nullptr;
-    if (m_expandingWidgets.contains(idx)) {
-        w = m_expandingWidgets[idx];
+    const auto widgetIt = m_expandingWidgets.constFind(idx);
+    if (widgetIt != m_expandingWidgets.constEnd()) {
+        w = *widgetIt;
     }
 
     if (w && isExpanded(idx)) {
@@ -491,8 +494,9 @@ QWidget* ExpandingWidgetModel::expandingWidget(const QModelIndex& idx_) const
 {
     QModelIndex idx(firstColumn(idx_));
 
-    if (m_expandingWidgets.contains(idx)) {
-        return m_expandingWidgets[idx];
+    const auto widgetIt = m_expandingWidgets.find(idx);
+    if (widgetIt != m_expandingWidgets.end()) {
+        return *widgetIt;
     } else {
         return nullptr;
     }
