@@ -68,7 +68,7 @@ TestView::TestView(TestViewPlugin* plugin, QWidget* parent)
     setWindowIcon(QIcon::fromTheme(QStringLiteral("preflight-verifier"), windowIcon()));
     setWindowTitle(i18n("Unit Tests"));
 
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    auto* layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     setLayout(layout);
     layout->addWidget(m_tree);
@@ -98,10 +98,10 @@ TestView::TestView(TestViewPlugin* plugin, QWidget* parent)
     connect (runSelected, &QAction::triggered, this, &TestView::runSelectedTests);
     addAction(runSelected);
 
-    QLineEdit* edit = new QLineEdit(parent);
+    auto* edit = new QLineEdit(parent);
     edit->setPlaceholderText(i18n("Filter..."));
     edit->setClearButtonEnabled(true);
-    QWidgetAction* widgetAction = new QWidgetAction(this);
+    auto* widgetAction = new QWidgetAction(this);
     widgetAction->setDefaultWidget(edit);
     connect(edit, &QLineEdit::textChanged, this, &TestView::changeFilter);
     addAction(widgetAction);
@@ -121,8 +121,8 @@ TestView::TestView(TestViewPlugin* plugin, QWidget* parent)
     connect (tc, &ITestController::testRunStarted,
              this, &TestView::notifyTestCaseStarted);
 
-    foreach (ITestSuite* suite, tc->testSuites())
-    {
+    const auto suites = tc->testSuites();
+    for (ITestSuite* suite : suites) {
         addTestSuite(suite);
     }
 }
@@ -148,10 +148,9 @@ void TestView::updateTestSuite(ITestSuite* suite, const TestResult& result)
     {
         qCDebug(PLUGIN_TESTVIEW) << "Found a test case" << item->child(i)->text();
         QStandardItem* caseItem = item->child(i);
-        if (result.testCaseResults.contains(caseItem->text()))
-        {
-            TestResult::TestCaseResult caseResult = result.testCaseResults.value(caseItem->text(), TestResult::NotRun);
-            caseItem->setIcon(iconForTestResult(caseResult));
+        const auto resultIt = result.testCaseResults.constFind(caseItem->text());
+        if (resultIt != result.testCaseResults.constEnd()) {
+            caseItem->setIcon(iconForTestResult(*resultIt));
         }
     }
 }
@@ -223,15 +222,12 @@ QIcon TestView::iconForTestResult(TestResult::TestCaseResult result)
 
 QStandardItem* TestView::itemForSuite(ITestSuite* suite)
 {
-    foreach (QStandardItem* item, m_model->findItems(suite->name(), Qt::MatchRecursive))
-    {
-        if (item->parent() && item->parent()->text() == suite->project()->name()
-            && !item->parent()->parent())
-        {
-            return item;
-        }
-    }
-    return nullptr;
+    const auto items = m_model->findItems(suite->name(), Qt::MatchRecursive);
+    auto it = std::find_if(items.begin(), items.end(), [&](QStandardItem* item) {
+        return (item->parent() && item->parent()->text() == suite->project()->name()
+                && !item->parent()->parent());
+    });
+    return (it != items.end()) ? *it : nullptr;
 }
 
 QStandardItem* TestView::itemForProject(IProject* project)
@@ -269,8 +265,7 @@ void TestView::runSelectedTests()
      * This is the somewhat-intuitive approach. Maybe a configuration should be offered.
      */
 
-    foreach (const QModelIndex& idx, indexes)
-    {
+    for (const QModelIndex& idx : qAsConst(indexes)) {
         QModelIndex index = m_filter->mapToSource(idx);
         if (index.parent().isValid() && indexes.contains(index.parent()))
         {
@@ -281,8 +276,8 @@ void TestView::runSelectedTests()
         {
             // A project was selected
             IProject* project = ICore::self()->projectController()->findProjectByName(item->data(ProjectRole).toString());
-            foreach (ITestSuite* suite, tc->testSuitesForProject(project))
-            {
+            const auto suites = tc->testSuitesForProject(project);
+            for (ITestSuite* suite : suites) {
                 jobs << suite->launchAllCases(ITestSuite::Silent);
             }
         }
@@ -305,7 +300,7 @@ void TestView::runSelectedTests()
 
     if (!jobs.isEmpty())
     {
-        KDevelop::ExecuteCompositeJob* compositeJob = new KDevelop::ExecuteCompositeJob(this, jobs);
+        auto* compositeJob = new KDevelop::ExecuteCompositeJob(this, jobs);
         compositeJob->setObjectName(i18np("Run 1 test", "Run %1 tests", jobs.size()));
         compositeJob->setProperty("test_job", true);
         ICore::self()->runController()->registerJob(compositeJob);
@@ -367,8 +362,8 @@ void TestView::addTestSuite(ITestSuite* suite)
     QStandardItem* suiteItem = new QStandardItem(QIcon::fromTheme(QStringLiteral("view-list-tree")), suite->name());
 
     suiteItem->setData(suite->name(), SuiteRole);
-    foreach (const QString& caseName, suite->cases())
-    {
+    const auto caseNames = suite->cases();
+    for (const QString& caseName : caseNames) {
         QStandardItem* caseItem = new QStandardItem(iconForTestResult(TestResult::NotRun), caseName);
         caseItem->setData(caseName, CaseRole);
         suiteItem->appendRow(caseItem);
